@@ -2,7 +2,7 @@
 
 from zstandard import ZstdCompressor as compressor
 from zstandard import ZstdDecompressor as decompressor
-from io import TextIOWrapper
+from io import TextIOWrapper, RawIOBase
 
 _open = open
 
@@ -31,14 +31,34 @@ class Write:
     self.file.close()
 
 
-class Read:
-  def __init__(self, file, encoding):
-    self.encoding = encoding
-    self.file = _open(file, "rb")
-    self.ctx = decompressor().stream_reader(self.file)
+class ByteIOWrapper:
+  def __init__(self, file):
+    self.file = file
+    self.iter = iter(self)
+
+  def __next__(self):
+    return next(self.iter)
 
   def __iter__(self):
-    return TextIOWrapper(self.ctx, encoding=self.encoding)
+    pre = b""
+    while True:
+      buf = self.file.read(16384)
+      if not buf:
+        return pre
+      li = (pre + buf).split(b"\n")
+      pre = li.pop()
+      for i in li:
+        yield i
+
+
+class Read:
+  def __init__(self, file, wrap):
+    self.file = _open(file, "rb")
+    self.ctx = decompressor().stream_reader(self.file)
+    self.wrap = wrap
+
+  def __iter__(self):
+    return self.wrap(self.ctx)
 
   def __enter__(self):
     return self
@@ -51,4 +71,8 @@ class Read:
 def open(file, mode='r', encoding="utf-8", level=10):
   if "w" in mode:
     return Write(file, encoding, level)
-  return Read(file, encoding)
+  if "b" in mode:
+    wrap = ByteIOWrapper
+  else:
+    wrap = lambda ctx: TextIOWrapper(ctx, encoding=encoding)
+  return Read(file, wrap)
